==> haskell-async-2.1.1.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1.1
id: async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy
key: async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
exposed-modules:
    Control.Concurrent.Async
abi: 62ed7cb248dd4b027b21ba3fa893bed7
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/async-2.1.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/async-2.1.1.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/async-2.1.1.1
hs-libraries: HSasync-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy
depends:
    base-4.9.1.0 stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-async-2.1.1.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1.1
id: async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
key: async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Async
abi: 877e0732f418402f16d143a5b45ef88e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/async-2.1.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/async-2.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/async-2.1.1.1
hs-libraries: HSasync-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
depends:
    base-4.10.0.0 stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=b0109b1e29ac5bcdebe44e0ece53e651
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
